@@ -164,6 +164,11 @@ sql_prefix <- function(f, n = NULL) {
   dbplyr::sql_prefix(f = f, n = n)
 }
 
+# registered onLoad
+sql_join_suffix.BigQueryConnection <- function(con, ...) {
+  c("_x", "_y")
+}
+
 # registered onLoad
 sql_translate_env.BigQueryConnection <- function(x) {
   dbplyr::sql_variant(
